.. -*- mode: rst -*-



sklearn-kmedoids-string
=======================================================================

This repo is forked from scikit-learn-extra, and removed validations to make kmedoids to work with string data for custom callable distance metric.

.. _scikit-learn: https://scikit-learn.org

scikit-learn-extra is a Python module for machine learning that extends scikit-learn. It includes algorithms that are useful but do not satisfy the scikit-learn `inclusion criteria <https://scikit-learn.org/stable/faq.html#what-are-the-inclusion-criteria-for-new-algorithms>`_, for instance due to their novelty or lower citation number.

This repo forked from scikit-learn-extra, and removed validations to make kmedoids to workd with string data for custom callable distance metric.

Installation
------------

Dependencies
^^^^^^^^^^^^

sklearn-kmedoids-string requires,

- Python (>=3.7)
- scikit-learn (>=0.24), and its dependencies


Installation
^^^^^^^^^^^^


Install from PyPi with,

.. code::

   pip install sklearn-kmedoids-on-string==0.3.0.dev0



